==> record_api-1.1.2.tar.gz: record_api-1.1.2/data/typing/pandas.core.arrays.sparse.array.py <==
from typing import *


class SparseArray:
    def __and__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 2
        """
        ...

    def __eq__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __ge__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __gt__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __iadd__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 1
        """
        ...

    def __le__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __mul__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 1
        """
        ...

    def __ne__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __or__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 2
        """
        ...

    def __radd__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rfloordiv__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rmod__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rmul__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rpow__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rsub__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rtruediv__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

==> record_api-1.3.2.tar.gz: record_api-1.3.2/data/typing/pandas.core.arrays.sparse.array.py <==
from typing import *


class SparseArray:

    # usage.dask: 1
    __module__: ClassVar[object]

    # usage.sklearn: 1
    __name__: ClassVar[object]

    # usage.sklearn: 1
    __class__: object

    def __and__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 2
        """
        ...

    def __eq__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __ge__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __gt__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __iadd__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 1
        """
        ...

    def __le__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __mul__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 1
        """
        ...

    def __ne__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __or__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 2
        """
        ...

    def __radd__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rfloordiv__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rmod__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rmul__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rpow__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rsub__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...

    def __rtruediv__(self, _0: Union[numpy.float64, numpy.ndarray], /):
        """
        usage.pandas: 3
        """
        ...
